@@ -2,9 +2,9 @@ package Test::MockPackages;
 use strict;
 use warnings;
 use utf8;
-use 5.010;
+use feature qw(state);
 
-our $VERSION = '0.10';
+our $VERSION = '0.2';
 
 use Carp qw(croak);
 use English qw(-no_match_vars);
@@ -89,12 +89,7 @@ sub _must_validate {
                     croak( "arguments must be an ARRAY for mock method $mock_method in ${pkg}::$sub" );
                 }
 
-                if (!do {
-                        local $EVAL_ERROR = undef;
-                        eval { Test::MockPackages::Mock->can( $mock_method ) };
-                    }
-                    )
-                {
+                if ( !eval { Test::MockPackages::Mock->can( $mock_method ) } ) {
                     croak( "$mock_method is not a capability of Test::MockPackages::Mock in ${pkg}::$sub" );
                 }
             }
@@ -104,17 +99,6 @@ sub _must_validate {
     return 1;
 }
 
-sub DESTROY {
-    my ( $self ) = @ARG;
-
-    # this is to ensure that the objects are destroyed in a consistent order.
-    for my $pkg ( sort keys %{ $self->{_packages} } ) {
-        delete $self->{_packages}{$pkg};
-    }
-
-    return;
-}
-
 1;
 
 __END__
@@ -127,7 +111,7 @@ Test::MockPackages - Mock external dependencies in tests
 
 =head1 VERSION
 
-Version 0.10
+Version 0.2
 
 =head1 SYNOPSIS
 
@@ -181,7 +165,7 @@ Version 0.10
 Test::MockPackages is a package for mocking other packages as well as ensuring those packages are being used correctly.
 
 Say we have a Weather class that can return the current degrees in Fahrenheit. In order to do this it uses another class, Weather::Fetcher which
-makes an external call. When we want to write a unit test for Weather, we want to mock the functionality of Weather::Fetcher.
+makes an external call. When we want to write a unit test for Weather, we want to mock the functionality of Weather::Fethcer.
 
 Here is the sample code for our Weather class:
 
@@ -355,6 +339,6 @@ Written by Tom Peters <tpeters at synacor.com>.
 
 =head1 COPYRIGHT
 
-Copyright (c) 2016 Synacor, Inc.
+Copyright (c), Synacor, Inc., 2016
 
 =cut
